@@ -1,22 +1,30 @@
 from flask_admin.base import AdminIndexView, expose
 from flask import Blueprint
+from shelf.security.mixin import LoginMixin
 
 config = {
     "name": "Dashboard",
     "description": "Dashboard-like view using tiles containing text and chart."
 }
 
-class DashboardView(AdminIndexView):
+class DashboardView(LoginMixin, AdminIndexView):
     widgets = []
 
-    def add_widget(self, view):
+    def __init__(self, *args, **kwargs):
+        if "template" not in kwargs:
+            kwargs["template"] = "dashboard.html"
+        return super(DashboardView, self).__init__(*args, **kwargs)
+
+    def add_widget(self, view, provider=None):
         if not self.widgets:
             self.widgets = []
+        if provider:
+            view.provider = provider
         self.widgets.append(view)
 
     @expose("/")
     def index(self):
-        return self.render(self._template, user=current_user, widgets=[w.render() for w in self.widgets])
+        return self.render(self._template, widgets=[w.render() for w in self.widgets])
 
 class Dashboard:
     def __init__(self):
