@@ -115,8 +115,11 @@ class RemoteFileField(TextField):
         super(RemoteFileField, self).__init__(*args, **kwargs)
 
     def process_formdata(self, valuelist):
-        if self.data:
-            self.data.set_path(valuelist[0])
+        if valuelist:
+            self.data = valuelist[0]
+
+    def process_data(self, value):
+        TextField.process_data(self, value)
 
     def populate_obj(self, obj, name):
         if getattr(obj, name) is None:
@@ -149,7 +152,7 @@ class PictureField(TextField):
                 getattr(obj, name).set_path(self.raw_data[0])
 
     def process_formdata(self, valuelist):
-        if self.data:            
+        if self.data:
             self.data.set_path(valuelist[0])
 
 
